powered by
Get theta from given spiral lengths
solve_theta_from_spiral_length(len, interval = NULL, offset = 0)
The theta value.
A vector of spiral lengths.
Interval to search for the solution.
Offset of the spiral. In the general form: r = a + r*theta, offset is the value of a.
r = a + r*theta
a
The length of the spiral has a complicated form, see https://downloads.imagej.net/fiji/snapshots/arc_length.pdf . Let's say the form is l = f(theta), solve_theta_from_spiral_length tries to find theta by a known l. It uses uniroot to search solutions.
l = f(theta)
solve_theta_from_spiral_length
l
uniroot
spiral_initialize() s = current_spiral() theta = pi*seq(2, 3, length = 10) len = s$spiral_length(theta) solve_theta_from_spiral_length(len) # should be very similar as theta
Run the code above in your browser using DataLab