Type of the highlighting. "rect" means drawing transparent rectangles covering the whole track. "line" means drawing annotation lines on top of the track or at the bottom of it.
padding
When the highlight type is "rect", it controls the padding of the highlighted region. The value should be a unit object or a numeric value which is the fraction of the length of the highlighted section. The length can be one or two. Note it only extends in the radial direction.
line_side
If the highlight type is "line", it controls which side of the track to draw the lines.
line_width
Width of the annotation line. Value should be a unit object.