Learn R Programming

spiralize (version 1.0.6)

spiral_initialize_by_gcoor: Initialize the spiral with genomic coordinates

Description

Initialize the spiral with genomic coordinates

Usage

spiral_initialize_by_gcoor(xlim, scale_by = "curve_length", ...)

Value

No value is returned.

Arguments

xlim

Range of the genomic coordinates.

scale_by

For genomic plot, axis is linearly scaled by the curve length.

...

All pass to spiral_initialize.

Details

It is basically the same as spiral_initialize. The only difference is the axis labels are automatically formated for genomic coordinates.

Examples

Run this code
spiral_initialize_by_gcoor(c(0, 1000000000))
spiral_track()
spiral_axis()

Run the code above in your browser using DataLab