spiral_opt: Global options
Description
Global options
Usage
spiral_opt(..., RESET = FALSE, READ.ONLY = NULL, LOCAL = FALSE, ADD = FALSE)
Arguments
- ...
Arguments for the parameters, see "details" section.
- RESET
Whether to reset to default values.
- READ.ONLY
Please ignore.
- LOCAL
Please ignore.
- ADD
Please ignore.
Details
There are following global parameters:
min_segment_len
Minimal length of the segment that partitions a curve.
To access the value of an option: spiral_opt$name where name is the name of the option. To set a new value
for an option: spiral_opt$name = new_value.