spiral_polygon: Add polygons to a track
Description
Add polygons to a track
Usage
spiral_polygon(x, y, id = NULL, gp = gpar(), track_index = current_track_index())
Value
No value is returned.
Arguments
- x
X-locations of the data points.
- y
Y-locations of the data points.
- id
A numeric vector used to separate locations in x and y into multiple polygons.
- gp
Graphical parameters.
- track_index
Index of the track.
Details
Note the polygon must be closed, which means, the last data point should overlap to the first one.