Learn R Programming

spiralize (version 1.0.6)

spiral_track: Add a new track or go to an existed track

Description

Add a new track or go to an existed track

Usage

spiral_track(ylim = c(0, 1), height = 0.8, background = TRUE,
    background_gp = gpar(col = NA, fill = "#EEEEEE"), reverse_y = FALSE,
    track_index = current_track_index() + 1)

Value

No value is returned.

Arguments

ylim

Data range of the y-locations.

height

Height of the track. The value can be the fraction of the distance of the two neighbour loops. The value can also be a unit object.

background

Whether to draw the background of the track, i.e. border and filled color of background.

background_gp

Graphics parameters of the background.

reverse_y

Whether reverse the direction of y-axis.

track_index

Index of the track.

Details

If the track is already existed, the function simply mark the track as the current track and does nothing else.

Examples

Run this code
spiral_initialize()
spiral_track(height = 0.8)

spiral_initialize()
spiral_track(height = 0.4, background_gp = gpar(fill = "red"))
spiral_track(height = 0.2, background_gp = gpar(fill = "green"))
spiral_track(height = 0.1, background_gp = gpar(fill = "blue"))

Run the code above in your browser using DataLab