Learn R Programming

spiralize (version 1.0.6)

xy_to_cartesian: Convert data coordinates to the canvas coordinates

Description

Convert data coordinates to the canvas coordinates

Usage

xy_to_cartesian(x, y, track_index = current_track_index())

Value

A data frame with two columns: x and y.

Arguments

x

X-locations of the data points.

y

Y-locations of the data points.

track_index

Index of the track.

Details

The canvas coordinates correspond to the "native" coordinates of the viewport where the graphics are to be drawn.

Note different settings of flip and reverse in spiral_initialize affect the conversion.

Examples

Run this code
# There is no example
NULL

Run the code above in your browser using DataLab