powered by
Initialize the spiral with genomic coordinates
spiral_initialize_by_gcoor(xlim, scale_by = "curve_length", ...)
No value is returned.
Range of the genomic coordinates.
For genomic plot, axis is linearly scaled by the curve length.
All pass to spiral_initialize.
spiral_initialize
It is basically the same as spiral_initialize. The only difference is the axis labels are automatically formated for genomic coordinates.
spiral_initialize_by_gcoor(c(0, 1000000000)) spiral_track() spiral_axis()
Run the code above in your browser using DataLab