powered by
Convert data coordinates to the canvas coordinates
xy_to_cartesian(x, y, track_index = current_track_index())
A data frame with two columns: x and y.
X-locations of the data points.
Y-locations of the data points.
Index of the track.
The canvas coordinates correspond to the "native" coordinates of the viewport where the graphics are to be drawn.
Note different settings of flip and reverse in spiral_initialize affect the conversion.
flip
reverse
spiral_initialize
# There is no example NULL
Run the code above in your browser using DataLab